package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.CabinetsMapper;
import com.zyc.system.domain.Cabinets;
import com.zyc.system.service.ICabinetsService;

/**
 * 机柜信息Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class CabinetsServiceImpl implements ICabinetsService 
{
    @Autowired
    private CabinetsMapper cabinetsMapper;

    /**
     * 查询机柜信息
     * 
     * @param id 机柜信息主键
     * @return 机柜信息
     */
    @Override
    public Cabinets selectCabinetsById(Integer id)
    {
        return cabinetsMapper.selectCabinetsById(id);
    }

    /**
     * 查询机柜信息列表
     * 
     * @param cabinets 机柜信息
     * @return 机柜信息
     */
    @Override
    public List<Cabinets> selectCabinetsList(Cabinets cabinets)
    {
        return cabinetsMapper.selectCabinetsList(cabinets);
    }

    /**
     * 新增机柜信息
     * 
     * @param cabinets 机柜信息
     * @return 结果
     */
    @Override
    public int insertCabinets(Cabinets cabinets)
    {
        return cabinetsMapper.insertCabinets(cabinets);
    }

    /**
     * 修改机柜信息
     * 
     * @param cabinets 机柜信息
     * @return 结果
     */
    @Override
    public int updateCabinets(Cabinets cabinets)
    {
        return cabinetsMapper.updateCabinets(cabinets);
    }

    /**
     * 批量删除机柜信息
     * 
     * @param ids 需要删除的机柜信息主键
     * @return 结果
     */
    @Override
    public int deleteCabinetsByIds(Integer[] ids)
    {
        return cabinetsMapper.deleteCabinetsByIds(ids);
    }

    /**
     * 删除机柜信息信息
     * 
     * @param id 机柜信息主键
     * @return 结果
     */
    @Override
    public int deleteCabinetsById(Integer id)
    {
        return cabinetsMapper.deleteCabinetsById(id);
    }
}
