package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.Cabinets;
import com.zyc.system.service.ICabinetsService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 机柜信息Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/CabinetsController")
public class CabinetsController extends BaseController
{
    @Autowired
    private ICabinetsService cabinetsService;

    /**
     * 查询机柜信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:cabinets:list')")
    @GetMapping("/list")
    public TableDataInfo list(Cabinets cabinets)
    {
        startPage();
        List<Cabinets> list = cabinetsService.selectCabinetsList(cabinets);
        return getDataTable(list);
    }

    /**
     * 导出机柜信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:cabinets:export')")
    @Log(title = "机柜信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Cabinets cabinets)
    {
        List<Cabinets> list = cabinetsService.selectCabinetsList(cabinets);
        ExcelUtil<Cabinets> util = new ExcelUtil<Cabinets>(Cabinets.class);
        util.exportExcel(response, list, "机柜信息数据");
    }

    /**
     * 获取机柜信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:cabinets:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(cabinetsService.selectCabinetsById(id));
    }

    /**
     * 新增机柜信息
     */
    @PreAuthorize("@ss.hasPermi('system:cabinets:add')")
    @Log(title = "机柜信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Cabinets cabinets)
    {
        return toAjax(cabinetsService.insertCabinets(cabinets));
    }

    /**
     * 修改机柜信息
     */
    @PreAuthorize("@ss.hasPermi('system:cabinets:edit')")
    @Log(title = "机柜信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Cabinets cabinets)
    {
        return toAjax(cabinetsService.updateCabinets(cabinets));
    }

    /**
     * 删除机柜信息
     */
    @PreAuthorize("@ss.hasPermi('system:cabinets:remove')")
    @Log(title = "机柜信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(cabinetsService.deleteCabinetsByIds(ids));
    }
}
